#[repr(u8)]pub enum TcmRwaitEn {
TCM_RWAIT_EN_0 = 0,
TCM_RWAIT_EN_1 = 1,
}Variants
TCM_RWAIT_EN_0 = 0
TCM read fast mode: Read RAM accesses are expected to be finished in 1-cycle.
TCM_RWAIT_EN_1 = 1
TCM read wait mode: Read RAM accesses are expected to be finished in 2-cycles.
Implementations
Sourceimpl TcmRwaitEn
impl TcmRwaitEn